@@ -21,8 +21,11 @@ class LocalMetadata():
 
         for idx in range(total_records):
             r = records[idx]
-            func = func_list[r.func_id]
-            self.function_count[r.func_id] += 1
+
+            # Ignore user functions for now
+            if r.func_id < len(func_list):
+                func = func_list[r.func_id]
+                self.function_count[r.func_id] += 1
 
             if "MPI" in func or "H5" in func: continue
 
